@@ -1,5 +1,4 @@
-from __future__ import print_function
-
+import configparser
 import os.path as Path
 import os
 import shutil
@@ -8,13 +7,8 @@ import sys
 from . import exceptions
 from .resources import Message
 
-try:  # Python 3 imports
-    import configparser
-except ImportError:  # Python 2 imports
-    import ConfigParser as configparser
 
-
-class Settings(object):
+class Settings:
     """
     This class handles settings for balena python SDK.
 
